@@ -952,7 +952,7 @@ __END__
 
 =cut
 
-use Test::More no_plan => 1;
+use Test::More qw(no_plan);
 use Test::Group;
 use File::Spec::Functions qw(catfile catdir);
 use IO::File;
